.. rst-class:: detail

SetWorkObject
========================

.. currentmodule:: compas_rrc

.. autoclass:: SetWorkObject

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetWorkObject.__init__
        ~SetWorkObject.from_msg
    
    